@@ -1,37 +1,14 @@
 use strict;
 use warnings;
-
 package Number::Tolerant::Constant;
-our $VERSION = "1.700";
+BEGIN {
+  $Number::Tolerant::Constant::VERSION = '1.701';
+}
+# ABSTRACT: a blessed constant type
 
-=head1 NAME
 
-Number::Tolerant::Constant - a blessed constant type
-
-=head1 VERSION
-
-version 1.700
-
-=head1 SYNOPSIS
-
- use Number::Tolerant;
- use Number::Tolerant::Constant;
-
- my $range  = tolerance(10);
- ref $range; # "Number::Tolerant" -- w/o ::Constant, would be undef
-
-=head1 DESCRIPTION
-
-When Number::Tolerant is about to return a tolerance with zero variation, it
-will return a constant instead.  This module will register a constant type that
-will catch these constants and return them as Number::Tolerant objects.
-
-I wrote this module to make it simpler to use tolerances with Class::DBI, which
-would otherwise complain that the constructor hadn't returned a blessed object.
-
-=cut
-
-package Number::Tolerant::Type::constant_obj;
+package
+  Number::Tolerant::Type::constant_obj;
 use base qw(Number::Tolerant::Type);
 
 sub construct { shift;
@@ -72,17 +49,46 @@ sub _disable {
   Number::Tolerant->enable_plugin( "Number::Tolerant::Type::constant");
 }
 
-=head1 TODO
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Number::Tolerant::Constant - a blessed constant type
+
+=head1 VERSION
+
+version 1.701
+
+=head1 SYNOPSIS
+
+ use Number::Tolerant;
+ use Number::Tolerant::Constant;
+
+ my $range  = tolerance(10);
+ ref $range; # "Number::Tolerant" -- w/o ::Constant, would be undef
+
+=head1 DESCRIPTION
+
+When Number::Tolerant is about to return a tolerance with zero variation, it
+will return a constant instead.  This module will register a constant type that
+will catch these constants and return them as Number::Tolerant objects.
+
+I wrote this module to make it simpler to use tolerances with Class::DBI, which
+would otherwise complain that the constructor hadn't returned a blessed object.
 
 =head1 AUTHOR
 
-Ricardo SIGNES, E<lt>rjbs@cpan.orgE<gt>
+Ricardo Signes <rjbs@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-(C) 2004-2006, Ricardo SIGNES.  Number::Tolerant::Constant is available under
-the same terms as Perl itself.
+This software is copyright (c) 2004 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
