@@ -1,11 +1,10 @@
 use strict;
 use warnings;
 
-package Number::Tolerant::Type::or_less;
+package
+  Number::Tolerant::Type::or_less;
 use base qw(Number::Tolerant::Type);
 
-our $VERSION = '1.700';
-
 sub construct { shift; { value => $_[0], max => $_[0] } }
 
 sub parse {
@@ -32,3 +31,28 @@ sub valid_args {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Number::Tolerant::Type::or_less
+
+=head1 VERSION
+
+version 1.701
+
+=head1 AUTHOR
+
+Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2004 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
